@@ -1,23 +1,49 @@
 #!/usr/bin/env python
 """The SCML universal command line tool"""
-from collections import defaultdict
 import math
 import os
 import sys
 import traceback
+from collections import defaultdict
 from functools import partial
 from pathlib import Path
-from pprint import pformat, pprint
+from pprint import pformat
+from pprint import pprint
 from time import perf_counter
-import numpy as np
 from typing import List
+
 import click
 import click_config_file
+import negmas
+import numpy as np
 import pandas as pd
-import progressbar
+import tqdm
 import yaml
+from negmas import save_stats
+from negmas.helpers import humanize_time
+from negmas.helpers import load
+from negmas.helpers import unique_name
+from negmas.java import jnegmas_bridge_is_running
 from tabulate import tabulate
 
+import scml
+from scml.oneshot import SCML2020OneShotWorld
+from scml.scml2019 import FactoryManager
+from scml.scml2019 import SCML2019World
+from scml.scml2019.utils import DefaultGreedyManager
+from scml.scml2019.utils import anac2019_collusion
+from scml.scml2019.utils import anac2019_sabotage
+from scml.scml2019.utils import anac2019_std
+from scml.scml2020 import SCML2020Agent
+from scml.scml2020 import SCML2020World
+from scml.scml2020 import SCML2021World
+from scml.scml2020 import is_system_agent
+from scml.scml2020.utils import anac2020_collusion
+from scml.scml2020.utils import anac2020_std
+from scml.scml2020.utils import anac2021_collusion
+from scml.scml2020.utils import anac2021_oneshot
+from scml.scml2020.utils import anac2021_std
+
 try:
     from scml.vendor.quick.quick import gui_option
 except:
@@ -26,25 +52,6 @@ except:
         return x
 
 
-import negmas
-from negmas import save_stats
-
-import scml
-from scml.scml2019 import SCML2019World, FactoryManager
-from scml.scml2019.utils import (
-    anac2019_std,
-    anac2019_sabotage,
-    anac2019_collusion,
-    DefaultGreedyManager,
-)
-from negmas.helpers import humanize_time, unique_name, load
-from negmas.java import jnegmas_bridge_is_running
-
-from scml.scml2020.utils import anac2020_std, anac2020_collusion
-from scml.scml2020.utils import anac2021_std, anac2021_collusion, anac2021_oneshot
-from scml.scml2020 import SCML2020Agent, SCML2020World, SCML2021World, is_system_agent
-from scml.oneshot import SCML2020OneShotWorld
-
 try:
     # disable a warning in yaml 1b1 version
     yaml.warnings({"YAMLLoadWarning": False})
@@ -261,7 +268,10 @@ def main():
     "paths on linux/mac and a ; separated list in windows",
 )
 @click.option(
-    "--output", default="", type=str, help="A file to save the final results to",
+    "--output",
+    default="",
+    type=str,
+    help="A file to save the final results to",
 )
 @click.option(
     "--cw",
@@ -577,7 +587,10 @@ def tournament2019(
     help="Run a parallel/serial tournament on a single machine",
 )
 @click.option(
-    "--output", default="", type=str, help="A file to save the final results to",
+    "--output",
+    default="",
+    type=str,
+    help="A file to save the final results to",
 )
 @click_config_file.configuration_option()
 def tournament2020(
@@ -957,7 +970,7 @@ def run2019(
     failed = False
     strt = perf_counter()
     try:
-        for i in progressbar.progressbar(range(world.n_steps), max_value=world.n_steps):
+        for i in tqdm.tqdm(range(world.n_steps)):
             elapsed = perf_counter() - strt
             if world.time_limit is not None and elapsed >= world.time_limit:
                 break
@@ -1224,7 +1237,7 @@ def run2020(
     failed = False
     strt = perf_counter()
     try:
-        for i in progressbar.progressbar(range(world.n_steps), max_value=world.n_steps):
+        for i in tqdm.tqdm(range(world.n_steps)):
             elapsed = perf_counter() - strt
             if world.time_limit is not None and elapsed >= world.time_limit:
                 break
@@ -1401,10 +1414,14 @@ def run2020(
 DEFAULT_STD = (
     "RandomAgent;BuyCheapSellExpensiveAgent;DecentralizingAgent;DoNothingAgent"
 )
-DEFAULT_ONESHOT = "RandomOneShotAgent;SyncRandomOneShotAgent"
+DEFAULT_STD_2021 = "MarketAwareDecentralizingAgent;scml.oneshot.agents.RandomOneShotAgent;DecentralizingAgent"
+# DEFAULT_STD_2021 = (
+#     "MarketAwareDecentralizingAgent;BuyCheapSellExpensiveAgent;DecentralizingAgent"
+# )
+DEFAULT_ONESHOT = "scml.scml2020.agents.DecentralizingAgent;RandomOneShotAgent;SyncRandomOneShotAgent;SingleAgreementRandomAgent;SingleAgreementAspirationAgent"
 DEFAULT_ONESHOT_FULL = [
-    "scml.oneshot.builtin.RandomOneShotAgent",
-    "scml.oneshot.builtin.SyncRandomOneShotAgent",
+    "scml.oneshot.agents.RandomOneShotAgent",
+    "scml.oneshot.agents.SingleAgreementAspirationAgent",
 ]
 
 
@@ -1484,7 +1501,7 @@ def run2021(
     oneshot,
 ):
     if not competitors:
-        competitors = DEFAULT_ONESHOT if oneshot else DEFAULT_STD
+        competitors = DEFAULT_ONESHOT if oneshot else DEFAULT_STD_2021
     world_type = SCML2020OneShotWorld if oneshot else SCML2021World
     if time <= 0:
         time = None
@@ -1514,14 +1531,14 @@ def run2021(
 
     def _no_default(s):
         return (not oneshot and not (s.startswith("scml.scml2020.agents."))) or (
-            oneshot and not (s.startswith("scml.oneshot.builtin."))
+            oneshot and not (s.startswith("scml.oneshot.agents."))
         )
 
     all_competitors = competitors.split(";")
     for i, cp in enumerate(all_competitors):
         if "." not in cp:
             if oneshot:
-                all_competitors[i] = "scml.oneshot.builtin." + cp
+                all_competitors[i] = "scml.oneshot.agents." + cp
             else:
                 all_competitors[i] = "scml.scml2020.agents." + cp
     all_competitors_params = [dict() for _ in all_competitors]
@@ -1543,7 +1560,7 @@ def run2021(
     failed = False
     strt = perf_counter()
     try:
-        for i in progressbar.progressbar(range(world.n_steps), max_value=world.n_steps):
+        for i in tqdm.tqdm(range(world.n_steps)):
             elapsed = perf_counter() - strt
             if world.time_limit is not None and elapsed >= world.time_limit:
                 break
@@ -1828,7 +1845,10 @@ def run2021(
     help="Run a parallel/serial tournament on a single machine",
 )
 @click.option(
-    "--output", default="", type=str, help="A file to save the final results to",
+    "--output",
+    default="",
+    type=str,
+    help="A file to save the final results to",
 )
 @click_config_file.configuration_option()
 def tournament2020(
@@ -1947,7 +1967,6 @@ def tournament2020(
     if non_competitors is None:
         non_competitors = scml.scml2020.utils.DefaultAgents
         non_competitor_params = tuple({} for _ in range(len(non_competitors)))
-    # breakpoint()
     print(f"Tournament will be run between {len(all_competitors)} agents: ")
     pprint(all_competitors)
     print("Non-competitors are: ")
@@ -2102,7 +2121,10 @@ def tournament2020(
     help="Run a parallel/serial tournament on a single machine",
 )
 @click.option(
-    "--output", default="", type=str, help="A file to save the final results to",
+    "--output",
+    default="",
+    type=str,
+    help="A file to save the final results to",
 )
 @click_config_file.configuration_option()
 def tournament2021(
@@ -2129,7 +2151,7 @@ def tournament2021(
 ):
     oneshot = ttype == "oneshot"
     if not competitors:
-        competitors = DEFAULT_ONESHOT if oneshot else DEFAULT_STD
+        competitors = DEFAULT_ONESHOT if oneshot else DEFAULT_STD_2021
     world_type = SCML2020OneShotWorld if oneshot else SCML2021World
     if len(output) == 0 or output == "none":
         output = None
@@ -2167,7 +2189,7 @@ def tournament2021(
     for i, cp in enumerate(all_competitors):
         if "." not in cp:
             if oneshot:
-                all_competitors[i] = ("scml.oneshot.builtin.") + cp
+                all_competitors[i] = ("scml.oneshot.agents.") + cp
             else:
                 all_competitors[i] = ("scml.scml2020.agents.") + cp
     all_competitors_params = [dict() for _ in range(len(all_competitors))]
@@ -2224,12 +2246,16 @@ def tournament2021(
         for i, cp in enumerate(non_competitors):
             if "." not in cp:
                 if oneshot:
-                    non_competitors[i] = ("scml.oneshot.builtin.") + cp
+                    non_competitors[i] = ("scml.oneshot.agents.") + cp
                 else:
                     non_competitors[i] = ("scml.scml2020.agents.") + cp
 
     if non_competitors is None:
-        non_competitors = DEFAULT_ONESHOT_FULL
+        non_competitors = (
+            DEFAULT_ONESHOT_FULL
+            if ttype == "oneshot"
+            else scml.scml2020.utils.DefaultAgents2021
+        )
         non_competitor_params = tuple({} for _ in range(len(non_competitors)))
     print(f"Tournament will be run between {len(all_competitors)} agents: ")
     pprint(all_competitors)
