@@ -3,27 +3,35 @@ import itertools
 import math
 import sys
 from os import PathLike
-from random import randint, random, shuffle, choices
+from random import choices
+from random import randint
+from random import random
+from random import shuffle
 
 import numpy as np
 from negmas import Agent
-from negmas.helpers import get_class, instantiate, unique_name, get_full_type_name
+from negmas.helpers import get_class
+from negmas.helpers import get_full_type_name
+from negmas.helpers import instantiate
+from negmas.helpers import unique_name
 from negmas.java import to_dict
 from negmas.situated import Entity
-from negmas.tournaments import WorldRunResults, TournamentResults, tournament
+from negmas.tournaments import TournamentResults
+from negmas.tournaments import WorldRunResults
+from negmas.tournaments import tournament
 
-from scml.scml2019.common import (
-    Product,
-    InputOutput,
-    Process,
-    ManufacturingProfile,
-    Factory,
-    DEFAULT_NEGOTIATOR,
-)
-from scml.scml2019.world import SCML2019World
-from scml.scml2019.consumers import JustInTimeConsumer, ConsumptionProfile
+from scml.scml2019.common import DEFAULT_NEGOTIATOR
+from scml.scml2019.common import Factory
+from scml.scml2019.common import InputOutput
+from scml.scml2019.common import ManufacturingProfile
+from scml.scml2019.common import Process
+from scml.scml2019.common import Product
+from scml.scml2019.consumers import ConsumptionProfile
+from scml.scml2019.consumers import JustInTimeConsumer
 from scml.scml2019.factory_managers.builtins import GreedyFactoryManager
-from scml.scml2019.miners import ReactiveMiner, MiningProfile
+from scml.scml2019.miners import MiningProfile
+from scml.scml2019.miners import ReactiveMiner
+from scml.scml2019.world import SCML2019World
 
 if True:
     from typing import (
