@@ -2,16 +2,15 @@
 Implements the `DecentralizingAgent` which creates ony buy and one sell controller for each time-step and relinquishes
 control of negotiations to buy/sell the required number of items of its input/output product.
 """
-from scml.scml2020.components import (
-    SupplyDrivenProductionStrategy,
-    MovingRangeNegotiationManager,
-)
-from ..components.trading import PredictionBasedTradingStrategy
+from scml.scml2020.components import MovingRangeNegotiationManager
+from scml.scml2020.components import SupplyDrivenProductionStrategy
 
-__all__ = ["MovingRangeAgent"]
-
-from ..world import SCML2020Agent
 from ..components import KeepOnlyGoodPrices
+from ..components.trading import PredictionBasedTradingStrategy
+from ..components.prediction import MarketAwareTradePredictionStrategy
+from ..world import SCML2020Agent
+
+__all__ = ["MovingRangeAgent", "MarketAwareMovingRangeAgent"]
 
 
 class MovingRangeAgent(
@@ -22,3 +21,7 @@ class MovingRangeAgent(
     SCML2020Agent,
 ):
     pass
+
+
+class MarketAwareMovingRangeAgent(MarketAwareTradePredictionStrategy, MovingRangeAgent):
+    pass
