@@ -3,26 +3,29 @@ import math
 from abc import abstractmethod
 from dataclasses import dataclass
 from pprint import pformat
-
-from typing import Tuple, List, Union, Any, Optional, Dict
+from typing import Any
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import Union
 
 import numpy as np
-
-from negmas import (
-    SAONegotiator,
-    AspirationNegotiator,
-    Issue,
-    AgentMechanismInterface,
-    Negotiator,
-    UtilityFunction,
-    Contract,
-)
-from negmas.helpers import get_class, instantiate
+from negmas import AgentMechanismInterface
+from negmas import AspirationNegotiator
+from negmas import Contract
+from negmas import Issue
+from negmas import Negotiator
+from negmas import SAONegotiator
+from negmas import UtilityFunction
+from negmas.helpers import get_class
+from negmas.helpers import instantiate
 
 from scml.scml2020 import AWI
-from scml.scml2020.components.prediction import MeanERPStrategy
-from scml.scml2020.services.controllers import StepController, SyncController
 from scml.scml2020.common import TIME
+from scml.scml2020.components.prediction import MeanERPStrategy
+from scml.scml2020.services.controllers import StepController
+from scml.scml2020.services.controllers import SyncController
 
 __all__ = [
     "NegotiationManager",
@@ -74,12 +77,19 @@ class NegotiationManager:
     """
 
     def __init__(
-        self, *args, horizon=5, negotiate_on_signing=True, logdebug=False, **kwargs
+        self,
+        *args,
+        horizon=5,
+        negotiate_on_signing=True,
+        logdebug=False,
+        use_trading_prices=True,
+        **kwargs,
     ):
         super().__init__(*args, **kwargs)
         self._horizon = horizon
         self._negotiate_on_signing = negotiate_on_signing
         self._log = logdebug
+        self._use_trading = use_trading_prices
 
     def init(self):
         # set horizon to exogenous horizon
@@ -211,12 +221,18 @@ class NegotiationManager:
         )
 
     def _urange(self, step, is_seller, time_range):
+        prices = (
+            self.awi.catalog_prices
+            if not self._use_trading
+            or not self.awi.settings.get("public_trading_prices", False)
+            else self.awi.trading_prices
+        )
         if is_seller:
-            cprice = self.awi.catalog_prices[self.awi.my_output_product]
-            return cprice, 2 * cprice
+            cprice = prices[self.awi.my_output_product]
+            return cprice, 2 * int(cprice + 0.5)
 
-        cprice = self.awi.catalog_prices[self.awi.my_input_product]
-        return 1, cprice
+        cprice = prices[self.awi.my_input_product]
+        return 1, int(cprice)
 
     def _trange(self, step, is_seller):
         if is_seller:
@@ -397,7 +413,7 @@ class StepNegotiationManager(MeanERPStrategy, NegotiationManager):
             expected_quantity = int(math.floor(qvalues[1] * self._execution_fraction))
 
         # negotiate with everyone
-        controller = self.add_controller(
+        controller = self.create_controller(
             sell, qvalues[1], uvalues, expected_quantity, step
         )
         # self.awi.loginfo_agent(
@@ -405,7 +421,7 @@ class StepNegotiationManager(MeanERPStrategy, NegotiationManager):
         #     f"on u={uvalues}, q={qvalues}, t={tvalues}"
         #     f" with {str(partners)} using {str(controller)}"
         # )
-        self.awi.request_negotiations(
+        if self.awi.request_negotiations(
             is_buy=not sell,
             product=product,
             quantity=qvalues,
@@ -414,7 +430,10 @@ class StepNegotiationManager(MeanERPStrategy, NegotiationManager):
             partners=partners,
             controller=controller,
             extra=dict(controller_index=step, is_seller=sell),
-        )
+        ):
+            self.add_controller(
+                controller, sell, qvalues[1], uvalues, expected_quantity, step
+            )
 
     def respond_to_negotiation_request(
         self,
@@ -442,7 +461,15 @@ class StepNegotiationManager(MeanERPStrategy, NegotiationManager):
         # )
         # create a controller for the time-step if one does not exist or use the one already running
         if controller_info.controller is None:
+            controller = self.create_controller(
+                is_seller,
+                target,
+                self._urange(step, is_seller, (tmin, tmax)),
+                int(target),
+                step,
+            )
             controller = self.add_controller(
+                controller,
                 is_seller,
                 target,
                 self._urange(step, is_seller, (tmin, tmax)),
@@ -453,7 +480,7 @@ class StepNegotiationManager(MeanERPStrategy, NegotiationManager):
             controller = controller_info.controller
 
         # create a new negotiator, add it to the controller and return it
-        return controller.create_negotiator()
+        return controller.create_negotiator(id=initiator)
 
     def all_negotiations_concluded(
         self, controller_index: int, is_seller: bool
@@ -485,6 +512,39 @@ class StepNegotiationManager(MeanERPStrategy, NegotiationManager):
             return
 
     def add_controller(
+        self,
+        controller: StepController,
+        is_seller: bool,
+        target,
+        urange: Tuple[int, int],
+        expected_quantity: int,
+        step: int,
+    ) -> StepController:
+        if is_seller:
+            # assert self.sellers[step].controller is None
+            self.sellers[step] = ControllerInfo(
+                controller,
+                step,
+                is_seller,
+                self._trange(step, is_seller),
+                target,
+                expected_quantity,
+                False,
+            )
+        else:
+            # assert self.buyers[step].controller is None
+            self.buyers[step] = ControllerInfo(
+                controller,
+                step,
+                is_seller,
+                self._trange(step, is_seller),
+                target,
+                expected_quantity,
+                False,
+            )
+        return controller
+
+    def create_controller(
         self,
         is_seller: bool,
         target,
@@ -496,7 +556,7 @@ class StepNegotiationManager(MeanERPStrategy, NegotiationManager):
             return self.sellers[step].controller
         if not is_seller and self.buyers[step].controller is not None:
             return self.buyers[step].controller
-        controller = StepController(
+        return StepController(
             is_seller=is_seller,
             target_quantity=target,
             negotiator_type=self.negotiator_type,
@@ -514,29 +574,6 @@ class StepNegotiationManager(MeanERPStrategy, NegotiationManager):
             parent_name=self.name,
             awi=self.awi,
         )
-        if is_seller:
-            assert self.sellers[step].controller is None
-            self.sellers[step] = ControllerInfo(
-                controller,
-                step,
-                is_seller,
-                self._trange(step, is_seller),
-                target,
-                expected_quantity,
-                False,
-            )
-        else:
-            assert self.buyers[step].controller is None
-            self.buyers[step] = ControllerInfo(
-                controller,
-                step,
-                is_seller,
-                self._trange(step, is_seller),
-                target,
-                expected_quantity,
-                False,
-            )
-        return controller
 
     def _get_controller(self, mechanism) -> StepController:
         neg = self._running_negotiations[mechanism.id]
@@ -604,9 +641,9 @@ class IndependentNegotiationsManager(NegotiationManager):
         # negotiate with all suppliers of the input product I need to produce
 
         issues = [
-            Issue(qvalues, name="quantity"),
-            Issue(tvalues, name="time"),
-            Issue(uvalues, name="uvalues"),
+            Issue((int(qvalues[0]), int(qvalues[1])), name="quantity"),
+            Issue((int(tvalues[0]), int(tvalues[1])), name="time"),
+            Issue((int(uvalues[0]), int(uvalues[1])), name="uvalues"),
         ]
 
         for partner in partners:
@@ -617,7 +654,7 @@ class IndependentNegotiationsManager(NegotiationManager):
                 unit_price=uvalues,
                 time=tvalues,
                 partner=partner,
-                negotiator=self.negotiator(sell, issues=issues),
+                negotiator=self.negotiator(sell, issues=issues, partner=partner),
             )
 
     def respond_to_negotiation_request(
@@ -627,7 +664,9 @@ class IndependentNegotiationsManager(NegotiationManager):
         annotation: Dict[str, Any],
         mechanism: AgentMechanismInterface,
     ) -> Optional[Negotiator]:
-        return self.negotiator(annotation["seller"] == self.id, issues=issues)
+        return self.negotiator(
+            annotation["seller"] == self.id, issues=issues, partner=initiator
+        )
 
     @abstractmethod
     def create_ufun(
@@ -635,7 +674,9 @@ class IndependentNegotiationsManager(NegotiationManager):
     ) -> UtilityFunction:
         """Creates a utility function"""
 
-    def negotiator(self, is_seller: bool, issues=None, outcomes=None) -> SAONegotiator:
+    def negotiator(
+        self, is_seller: bool, issues=None, outcomes=None, partner=None
+    ) -> SAONegotiator:
         """Creates a negotiator"""
         if outcomes is None and (
             issues is None or not Issue.enumerate(issues, astype=tuple)
@@ -645,7 +686,7 @@ class IndependentNegotiationsManager(NegotiationManager):
         params["ufun"] = self.create_ufun(
             is_seller=is_seller, outcomes=outcomes, issues=issues
         )
-        return instantiate(self.negotiator_type, **params)
+        return instantiate(self.negotiator_type, id=partner, **params)
 
 
 class MovingRangeNegotiationManager:
