@@ -1,6 +1,12 @@
 from abc import abstractmethod
-from typing import Union, Iterable, List, Optional
+from typing import Iterable
+from typing import List
+from typing import Optional
+from typing import Union
+
 import numpy as np
+from negmas import Breach
+from negmas import Contract
 
 __all__ = [
     "TradePredictionStrategy",
@@ -8,10 +14,9 @@ __all__ = [
     "ExecutionRatePredictionStrategy",
     "FixedERPStrategy",
     "MeanERPStrategy",
+    "MarketAwareTradePredictionStrategy",
 ]
 
-from negmas import Contract, Breach
-
 
 class TradePredictionStrategy:
     """A prediction strategy for expected inputs and outputs at every step
@@ -222,6 +227,76 @@ class FixedTradePredictionStrategy(TradePredictionStrategy):
                 self.expected_inputs[t] += q
 
 
+class MarketAwareTradePredictionStrategy(TradePredictionStrategy):
+    """
+    Predicts an amount based on publicly available market information. Falls
+    back to fixed prediction if no information is available
+
+    Hooks Into:
+        - `internal_state`
+        - `on_contracts_finalized`
+
+    Remarks:
+        - `Attributes` section describes the attributes that can be used to construct the component (passed to its
+          `__init__` method).
+        - `Provides` section describes the attributes (methods, properties, data-members) made available by this
+          component directly. Note that everything provided by the bases of this components are also available to the
+          agent (Check the `Bases` section above for all the bases of this component).
+        - `Requires` section describes any requirements from the agent using this component. It defines a set of methods
+          or properties/data-members that must exist in the agent that uses this component. These requirement are
+          usually implemented as abstract methods in the component
+        - `Abstract` section describes abstract methods that MUST be implemented by any descendant of this component.
+        - `Hooks Into` section describes the methods this component overrides calling `super` () which allows other
+          components to hook into the same method (by overriding it). Usually callbacks starting with `on_` are
+          hooked into this way.
+        - `Overrides` section describes the methods this component overrides without calling `super` effectively
+          disallowing any other components after it in the MRO to call this method. Usually methods that do some
+          action (i.e. not starting with `on_`) are overridden this way.
+
+    """
+
+    def trade_prediction_init(self):
+        inp = self.awi.my_input_product
+
+        def adjust(x, demand):
+            """Adjust the predicted demand/supply filling it with a default value or repeating as needed"""
+            if x is None:
+                x = max(1, self.awi.n_lines // 2)
+            elif isinstance(x, Iterable):
+                return np.array(x)
+            predicted = int(x) * np.ones(self.awi.n_steps, dtype=int)
+            if demand:
+                predicted[: inp + 1] = 0
+            else:
+                predicted[inp - self.awi.n_processes :] = 0
+            return predicted
+
+        # adjust predicted demand and supply
+        self.expected_outputs = adjust(self.expected_outputs, True)
+        self.expected_inputs = adjust(self.expected_inputs, False)
+
+    def trade_prediction_step(self):
+        exogenous = self.awi.exogenous_contract_summary
+        horizon = self.awi.settings.get("horizon", 1)
+        a, b = self.awi.current_step, self.awi.current_step + horizon
+        # breakpoint()
+        self.expected_inputs[a:b] = exogenous[self.awi.my_input_product, a:b, 0]
+        self.expected_outputs[a:b] = exogenous[self.awi.my_output_product, a:b, 0]
+
+    @property
+    def internal_state(self):
+        state = super().internal_state
+        state.update(
+            {
+                "expected_inputs": self.expected_inputs,
+                "expected_outputs": self.expected_outputs,
+                "input_cost": self.input_cost,
+                "output_price": self.output_price,
+            }
+        )
+        return state
+
+
 class FixedERPStrategy(ExecutionRatePredictionStrategy):
     """Predicts that the there is a fixed execution rate that does not change for all partners
 
