@@ -1,6 +1,7 @@
 __all__ = ["SignAll", "SignAllPossible", "KeepOnlyGoodPrices"]
 
-from typing import List, Optional
+from typing import List
+from typing import Optional
 
 from negmas import Contract
 
@@ -147,4 +148,3 @@ class KeepOnlyGoodPrices:
             ):
                 signatures[i] = None
         return signatures
-
