@@ -2,14 +2,24 @@
 
 import math
 import sys
-from abc import ABC, abstractmethod
+from abc import ABC
+from abc import abstractmethod
 from collections import defaultdict
-from typing import Dict, List, Optional, Tuple, Union
-import numpy as np
-from dataclasses import dataclass, field
 from contextlib import contextmanager
+from dataclasses import dataclass
+from dataclasses import field
+from typing import Dict
+from typing import List
+from typing import Optional
+from typing import Tuple
+from typing import Union
 
-from scml.scml2020 import FactoryProfile, NO_COMMAND, ANY_STEP, ANY_LINE
+import numpy as np
+
+from scml.scml2020 import ANY_LINE
+from scml.scml2020 import ANY_STEP
+from scml.scml2020 import NO_COMMAND
+from scml.scml2020 import FactoryProfile
 
 __all__ = ["FactorySimulator", "transaction", "temporary_transaction"]
 
