@@ -1,20 +1,29 @@
 import copy
+from collections import defaultdict
 from os import PathLike
-from random import randint, random, shuffle
+from random import randint
+from random import random
+from random import shuffle
 
 import numpy as np
 from negmas import Agent
-from negmas.helpers import unique_name, get_full_type_name
-from negmas.tournaments import WorldRunResults, TournamentResults, tournament
-from scml.scml2020.agents import (
-    DecentralizingAgent,
-    BuyCheapSellExpensiveAgent,
-    RandomAgent,
-)
-from scml.scml2020.world import SCML2020World, is_system_agent
-from collections import defaultdict
+from negmas.helpers import get_full_type_name
+from negmas.helpers import unique_name
+from negmas.tournaments import TournamentResults
+from negmas.tournaments import WorldRunResults
+from negmas.tournaments import tournament
 
 from scml.oneshot.world import SCML2020OneShotWorld
+from scml.scml2020.agents import BuyCheapSellExpensiveAgent
+from scml.scml2020.agents import (
+    DecentralizingAgent,
+    MarketAwareDecentralizingAgent,
+    MarketAwareIndDecentralizingAgent,
+    MarketAwareMovingRangeAgent,
+)
+from scml.scml2020.world import SCML2020World
+from scml.scml2020.world import is_system_agent
+from scml.oneshot.agents import RandomOneShotAgent, SyncRandomOneShotAgent
 
 if True:
     from typing import (
@@ -42,12 +51,31 @@ __all__ = [
     "balance_calculator2021",
     "balance_calculator2021oneshot",
     "DefaultAgents",
+    "DefaultAgents2021",
+    "DefaultAgentsOneShot",
 ]
 
+
 ROUND_ROBIN = True
+
+
 DefaultAgents = [DecentralizingAgent, BuyCheapSellExpensiveAgent]
 
 
+DefaultAgents2021 = [
+    DecentralizingAgent,
+    MarketAwareDecentralizingAgent,
+    MarketAwareIndDecentralizingAgent,
+    RandomOneShotAgent,
+]
+
+
+DefaultAgentsOneShot = [
+    RandomOneShotAgent,
+    SyncRandomOneShotAgent,
+]
+
+
 def integer_cut(
     n: int,
     l: int,
@@ -1461,14 +1489,14 @@ def anac2021_oneshot(
     #     competitor_params = [dict() for _ in range(len(competitors))]
     # for t, p in zip(competitors, competitor_params):
     #     p["controller_type"] = get_full_type_name(t)
-    # competitors = ["scml.oneshot.world._OneShotAdapter"] * len(competitors)
+    # competitors = ["scml.oneshot.world.DefaultOneShotAdapter"] * len(competitors)
     if n_competitors_per_world is None:
         n_competitors_per_world = kwargs.get(
             "n_competitors_per_world", randint(2, min(4, len(competitors)))
         )
     kwargs.pop("n_competitors_per_world", None)
     if non_competitors is None:
-        non_competitors = ["scml.oneshot.builtin.RandomOneShotAgent"]
+        non_competitors = ["scml.oneshot.agents.RandomOneShotAgent"]
         non_competitor_params = [dict() for _ in non_competitors]
     kwargs["round_robin"] = kwargs.get("round_robin", ROUND_ROBIN)
     kwargs["oneshot_world"] = True
