@@ -1,26 +1,31 @@
+import random
+
+import hypothesis.strategies as st
+from hypothesis import example
+from hypothesis import given
+from hypothesis import settings
+from hypothesis import reproduce_failure
 from negmas import save_stats
 from negmas.helpers import unique_name
 from pytest import mark
-from hypothesis import given, settings
-import hypothesis.strategies as st
 
-from scml.scml2020 import (
-    SCML2021World,
-    DoNothingAgent,
-    RandomAgent,
-    BuyCheapSellExpensiveAgent,
-    is_system_agent,
-)
+import scml
+from scml.oneshot.agents import RandomOneShotAgent
+from scml.oneshot.agents import SyncRandomOneShotAgent
+from scml.scml2020 import BuyCheapSellExpensiveAgent
+from scml.scml2020 import DoNothingAgent
+from scml.scml2020 import RandomAgent
+from scml.scml2020 import SCML2021World
+from scml.scml2020 import is_system_agent
 from scml.scml2020.agents.decentralizing import DecentralizingAgent
 
-import random
-
 random.seed(0)
 
 COMPACT = True
 NOLOGS = True
 # agent types to be tested
-types = [DoNothingAgent, RandomAgent, BuyCheapSellExpensiveAgent, DecentralizingAgent]
+types = scml.scml2020.builtin_agent_types(as_str=False)
+oneshot_types = scml.oneshot.builtin_agent_types(as_str=False)
 active_types = [_ for _ in types if _ != DoNothingAgent]
 
 
@@ -34,7 +39,8 @@ def generate_world(
     buy_missing_products=True,
     **kwargs,
 ):
-
+    kwargs["no_logs"] = True
+    kwargs["compact"] = True
     world = SCML2021World(
         **SCML2021World.generate(
             agent_types,
@@ -71,7 +77,7 @@ def generate_world(
 
 @mark.parametrize("agent_type", types)
 @given(buy_missing=st.booleans(), n_processes=st.integers(2, 4))
-@settings(deadline=300_000, max_examples=20)
+@settings(deadline=500_000, max_examples=20)
 def test_can_run_with_a_single_agent_type(agent_type, buy_missing, n_processes):
     world = generate_world(
         [agent_type],
@@ -101,7 +107,12 @@ def test_can_run_with_a_single_agent_type(agent_type, buy_missing, n_processes):
     n_processes=st.integers(2, 4),
 )
 @settings(deadline=300_000, max_examples=20)
-def test_can_run_with_a_multiple_agent_types(agent_types, buy_missing, n_processes):
+@example(
+    [RandomAgent, SyncRandomOneShotAgent],
+    False,
+    2,
+)
+def test_can_run_with_multiple_agent_types(agent_types, buy_missing, n_processes):
     world = generate_world(
         agent_types,
         buy_missing_products=buy_missing,
@@ -123,7 +134,7 @@ def test_can_run_with_a_multiple_agent_types(agent_types, buy_missing, n_process
 @given(
     buy_missing=st.booleans(),
     n_processes=st.integers(2, 4),
-    initial_balance=st.sampled_from([0, 50, 10_000, 10_000_000]),
+    initial_balance=st.sampled_from([50, 10_000, 10_000_000]),
 )
 def test_nothing_happens_with_do_nothing(buy_missing, n_processes, initial_balance):
     world = generate_world(
@@ -282,5 +293,37 @@ def test_graphs_lead_to_no_unknown_nodes():
             agent_types=[DecentralizingAgent, BuyCheapSellExpensiveAgent], n_steps=10
         ),
         construct_graphs=True,
+        no_logs=True,
     )
     world.graph((0, world.n_steps))
+
+
+@given(
+    atype=st.lists(
+        st.sampled_from(oneshot_types + types), unique=True, min_size=2, max_size=6
+    )
+)
+@settings(deadline=300_000, max_examples=30)
+def test_adapter(atype):
+    world = SCML2021World(
+        **SCML2021World.generate(agent_types=atype, n_steps=10),
+        construct_graphs=False,
+        no_logs=True,
+        compact=True,
+    )
+    world.run()
+
+def test_adapter_example():
+    world = SCML2021World(
+        **SCML2021World.generate(
+            agent_types=[
+                "scml.oneshot.agents.SingleAgreementAspirationAgent", 
+                "scml.scml2020.DecentralizingAgent"
+                ], 
+            n_steps=10
+        ),
+        construct_graphs=False,
+        no_logs=True,
+        compact=True,
+    )
+    world.run()
